@@ -1,24 +1,23 @@
+from __future__ import annotations
+
 import compileall
+import contextlib
 import fnmatch
-import io
+import http.server
 import os
 import re
 import shutil
 import subprocess
 import sys
-from contextlib import ExitStack, contextmanager
+import threading
+from collections.abc import Iterable, Iterator
+from contextlib import AbstractContextManager
+from dataclasses import dataclass
+from enum import Enum
+from hashlib import sha256
 from pathlib import Path
-from typing import (
-    TYPE_CHECKING,
-    AnyStr,
-    Callable,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    Optional,
-    Union,
-)
+from textwrap import dedent
+from typing import TYPE_CHECKING, Any, AnyStr, Callable, ClassVar
 from unittest.mock import patch
 from zipfile import ZipFile
 
@@ -36,24 +35,23 @@ from installer.destinations import SchemeDictionaryDestination
 from installer.sources import WheelFile
 
 from pip import __file__ as pip_location
-from pip._internal.cli.main import main as pip_entry_point
 from pip._internal.locations import _USE_SYSCONFIG
 from pip._internal.utils.temp_dir import global_tempdir_manager
-from tests.lib import DATA_DIR, SRC_DIR, PipTestEnvironment, TestData
-from tests.lib.server import MockServer as _MockServer
-from tests.lib.server import make_mock_server, server_running
+
+from tests.lib import (
+    DATA_DIR,
+    SRC_DIR,
+    CertFactory,
+    InMemoryPip,
+    PipTestEnvironment,
+    ScriptFactory,
+    TestData,
+)
+from tests.lib.server import MockServer, make_mock_server
 from tests.lib.venv import VirtualEnvironment, VirtualEnvironmentType
 
-from .lib.compat import nullcontext
-
 if TYPE_CHECKING:
-    from typing import Protocol
-
-    from wsgi import WSGIApplication
-else:
-    # TODO: Protocol was introduced in Python 3.8. Remove this branch when
-    # dropping support for Python 3.7.
-    Protocol = object
+    from typing_extensions import Self
 
 
 def pytest_addoption(parser: Parser) -> None:
@@ -66,8 +64,8 @@ def pytest_addoption(parser: Parser) -> None:
     parser.addoption(
         "--resolver",
         action="store",
-        default="2020-resolver",
-        choices=["2020-resolver", "legacy"],
+        default="resolvelib",
+        choices=["resolvelib", "legacy"],
         help="use given resolver in tests",
     )
     parser.addoption(
@@ -96,7 +94,7 @@ def pytest_addoption(parser: Parser) -> None:
     )
 
 
-def pytest_collection_modifyitems(config: Config, items: List[pytest.Function]) -> None:
+def pytest_collection_modifyitems(config: Config, items: list[pytest.Function]) -> None:
     for item in items:
         if not hasattr(item, "module"):  # e.g.: DoctestTextfile
             continue
@@ -104,6 +102,10 @@ def pytest_collection_modifyitems(config: Config, items: List[pytest.Function])
         if item.get_closest_marker("search") and not config.getoption("--run-search"):
             item.add_marker(pytest.mark.skip("pip search test skipped"))
 
+        # Exempt tests known to use the network from pytest-subket.
+        if item.get_closest_marker("network") is not None:
+            item.add_marker(pytest.mark.enable_socket)
+
         if "CI" in os.environ:
             # Mark network tests as flaky
             if item.get_closest_marker("network") is not None:
@@ -124,11 +126,7 @@ def pytest_collection_modifyitems(config: Config, items: List[pytest.Function])
         )
 
         module_root_dir = module_path.split(os.pathsep)[0]
-        if (
-            module_root_dir.startswith("functional")
-            or module_root_dir.startswith("integration")
-            or module_root_dir.startswith("lib")
-        ):
+        if module_root_dir.startswith(("functional", "integration", "lib")):
             item.add_marker(pytest.mark.integration)
         elif module_root_dir.startswith("unit"):
             item.add_marker(pytest.mark.unit)
@@ -138,7 +136,7 @@ def pytest_collection_modifyitems(config: Config, items: List[pytest.Function])
             if "script" in item.fixturenames:
                 raise RuntimeError(
                     "Cannot use the ``script`` funcarg in a unit test: "
-                    "(filename = {}, item = {})".format(module_path, item)
+                    f"(filename = {module_path}, item = {item})"
                 )
         else:
             raise RuntimeError(f"Unknown test type (filename = {module_path})")
@@ -209,7 +207,7 @@ def tmp_path(request: pytest.FixtureRequest, tmp_path: Path) -> Iterator[Path]:
         shutil.rmtree(tmp_path, ignore_errors=True)
 
 
-@pytest.fixture()
+@pytest.fixture
 def tmpdir(tmp_path: Path) -> Path:
     """Override Pytest's ``tmpdir`` with our pathlib implementation.
 
@@ -311,6 +309,10 @@ def isolate(tmpdir: Path, monkeypatch: pytest.MonkeyPatch) -> None:
     # Make sure tests don't share a requirements tracker.
     monkeypatch.delenv("PIP_BUILD_TRACKER", False)
 
+    # Make sure color control variables don't affect internal output.
+    monkeypatch.delenv("FORCE_COLOR", False)
+    monkeypatch.delenv("NO_COLOR", False)
+
     # FIXME: Windows...
     os.makedirs(os.path.join(home_dir, ".config", "git"))
     with open(os.path.join(home_dir, ".config", "git", "config"), "wb") as fp:
@@ -325,7 +327,7 @@ def scoped_global_tempdir_manager(request: pytest.FixtureRequest) -> Iterator[No
     temporary directories in the application.
     """
     if "no_auto_tempdir_manager" in request.keywords:
-        ctx = nullcontext
+        ctx: Callable[[], AbstractContextManager[None]] = contextlib.nullcontext
     else:
         ctx = global_tempdir_manager
 
@@ -335,7 +337,7 @@ def scoped_global_tempdir_manager(request: pytest.FixtureRequest) -> Iterator[No
 
 @pytest.fixture(scope="session")
 def pip_src(tmpdir_factory: pytest.TempPathFactory) -> Path:
-    def not_code_files_and_folders(path: str, names: List[str]) -> Iterable[str]:
+    def not_code_files_and_folders(path: str, names: list[str]) -> Iterable[str]:
         # In the root directory...
         if os.path.samefile(path, SRC_DIR):
             # ignore all folders except "src"
@@ -365,11 +367,45 @@ def pip_src(tmpdir_factory: pytest.TempPathFactory) -> Path:
     return pip_src
 
 
+@pytest.fixture(scope="session")
+def pip_editable_parts(
+    pip_src: Path, tmpdir_factory: pytest.TempPathFactory
+) -> tuple[Path, ...]:
+    pip_editable = tmpdir_factory.mktemp("pip") / "pip"
+    shutil.copytree(pip_src, pip_editable, symlinks=True)
+    # noxfile.py is Python 3 only
+    assert compileall.compile_dir(
+        pip_editable,
+        quiet=1,
+        rx=re.compile("noxfile.py$"),
+    )
+    pip_self_install_path = tmpdir_factory.mktemp("pip_self_install")
+    subprocess.check_call(
+        [
+            sys.executable,
+            "-m",
+            "pip",
+            "install",
+            "--no-build-isolation",
+            "--target",
+            pip_self_install_path,
+            "-e",
+            pip_editable,
+        ]
+    )
+    pth = next(pip_self_install_path.glob("*pip*.pth"))
+    dist_info = next(pip_self_install_path.glob("*.dist-info"))
+    return (pth, dist_info)
+
+
 def _common_wheel_editable_install(
     tmpdir_factory: pytest.TempPathFactory, common_wheels: Path, package: str
 ) -> Path:
     wheel_candidates = list(common_wheels.glob(f"{package}-*.whl"))
-    assert len(wheel_candidates) == 1, wheel_candidates
+    assert len(wheel_candidates) == 1, (
+        f"Missing wheels in {common_wheels}, expected 1 got '{wheel_candidates}'."
+        " Are you running the tests via nox? See https://pip.pypa.io/en/latest/development/getting-started/#running-tests"
+    )
     install_dir = tmpdir_factory.mktemp(package) / "install"
     lib_install_dir = install_dir / "lib"
     bin_install_dir = install_dir / "bin"
@@ -415,6 +451,18 @@ def coverage_install(
     return _common_wheel_editable_install(tmpdir_factory, common_wheels, "coverage")
 
 
+@pytest.fixture(scope="session")
+def socket_install(tmpdir_factory: pytest.TempPathFactory, common_wheels: Path) -> Path:
+    lib_dir = _common_wheel_editable_install(
+        tmpdir_factory, common_wheels, "pytest_subket"
+    )
+    # pytest-subket is only included so it can intercept and block unexpected
+    # network requests. It should NOT be visible to the pip under test.
+    dist_info = next(lib_dir.glob("*.dist-info"))
+    shutil.rmtree(dist_info)
+    return lib_dir
+
+
 def install_pth_link(
     venv: VirtualEnvironment, project_name: str, lib_dir: Path
 ) -> None:
@@ -428,10 +476,12 @@ def virtualenv_template(
     request: pytest.FixtureRequest,
     tmpdir_factory: pytest.TempPathFactory,
     pip_src: Path,
+    pip_editable_parts: tuple[Path, ...],
     setuptools_install: Path,
     wheel_install: Path,
     coverage_install: Path,
-) -> Iterator[VirtualEnvironment]:
+    socket_install: Path,
+) -> VirtualEnvironment:
     venv_type: VirtualEnvironmentType
     if request.config.getoption("--use-venv"):
         venv_type = "venv"
@@ -442,20 +492,24 @@ def virtualenv_template(
     tmpdir = tmpdir_factory.mktemp("virtualenv")
     venv = VirtualEnvironment(tmpdir.joinpath("venv_orig"), venv_type=venv_type)
 
-    # Install setuptools, wheel and pip.
+    # Install setuptools, wheel, pytest-subket, and pip.
     install_pth_link(venv, "setuptools", setuptools_install)
     install_pth_link(venv, "wheel", wheel_install)
-    pip_editable = tmpdir_factory.mktemp("pip") / "pip"
-    shutil.copytree(pip_src, pip_editable, symlinks=True)
-    # noxfile.py is Python 3 only
-    assert compileall.compile_dir(
-        str(pip_editable),
-        quiet=1,
-        rx=re.compile("noxfile.py$"),
-    )
-    subprocess.check_call(
-        [os.fspath(venv.bin / "python"), "setup.py", "-q", "develop"], cwd=pip_editable
+    install_pth_link(venv, "pytest_subket", socket_install)
+    # Also copy pytest-subket's .pth file so it can intercept socket calls.
+    with open(venv.site / "pytest_socket.pth", "w") as f:
+        f.write(socket_install.joinpath("pytest_socket.pth").read_text())
+
+    pth, dist_info = pip_editable_parts
+
+    shutil.copy(pth, venv.site)
+    shutil.copytree(
+        dist_info, venv.site / dist_info.name, dirs_exist_ok=True, symlinks=True
     )
+    # Create placeholder ``easy-install.pth``, as several tests depend on its
+    # existence.  TODO: Ensure ``tests.lib.TestPipResult.files_updated`` correctly
+    # detects changed files.
+    venv.site.joinpath("easy-install.pth").touch()
 
     # Install coverage and pth file for executing it in any spawned processes
     # in this virtual environment.
@@ -466,17 +520,14 @@ def virtualenv_template(
 
     # Drop (non-relocatable) launchers.
     for exe in os.listdir(venv.bin):
-        if not (
-            exe.startswith("python")
-            or exe.startswith("libpy")  # Don't remove libpypy-c.so...
-        ):
+        if not exe.startswith(("python", "libpy")):  # Don't remove libpypy-c.so...
             (venv.bin / exe).unlink()
 
     # Rename original virtualenv directory to make sure
     # it's not reused by mistake from one of the copies.
     venv_template = tmpdir / "venv_template"
     venv.move(venv_template)
-    yield venv
+    return venv
 
 
 @pytest.fixture(scope="session")
@@ -492,36 +543,26 @@ def virtualenv_factory(
 @pytest.fixture
 def virtualenv(
     virtualenv_factory: Callable[[Path], VirtualEnvironment], tmpdir: Path
-) -> Iterator[VirtualEnvironment]:
+) -> VirtualEnvironment:
     """
     Return a virtual environment which is unique to each test function
     invocation created inside of a sub directory of the test function's
     temporary directory. The returned object is a
     ``tests.lib.venv.VirtualEnvironment`` object.
     """
-    yield virtualenv_factory(tmpdir.joinpath("workspace", "venv"))
-
-
-class ScriptFactory(Protocol):
-    def __call__(
-        self,
-        tmpdir: Path,
-        virtualenv: Optional[VirtualEnvironment] = None,
-        environ: Optional[Dict[AnyStr, AnyStr]] = None,
-    ) -> PipTestEnvironment:
-        ...
+    return virtualenv_factory(tmpdir.joinpath("workspace", "venv"))
 
 
 @pytest.fixture(scope="session")
 def script_factory(
     virtualenv_factory: Callable[[Path], VirtualEnvironment],
     deprecated_python: bool,
-    zipapp: Optional[str],
+    zipapp: str | None,
 ) -> ScriptFactory:
     def factory(
         tmpdir: Path,
-        virtualenv: Optional[VirtualEnvironment] = None,
-        environ: Optional[Dict[AnyStr, AnyStr]] = None,
+        virtualenv: VirtualEnvironment | None = None,
+        environ: dict[AnyStr, AnyStr] | None = None,
     ) -> PipTestEnvironment:
         kwargs = {}
         if environ:
@@ -583,7 +624,7 @@ def make_zipapp_from_pip(zipapp_name: Path) -> None:
 @pytest.fixture(scope="session")
 def zipapp(
     request: pytest.FixtureRequest, tmpdir_factory: pytest.TempPathFactory
-) -> Optional[str]:
+) -> str | None:
     """
     If the user requested for pip to be run from a zipapp, build that zipapp
     and return its location. If the user didn't request a zipapp, return None.
@@ -631,26 +672,6 @@ def data(tmpdir: Path) -> TestData:
     return TestData.copy(tmpdir.joinpath("data"))
 
 
-class InMemoryPipResult:
-    def __init__(self, returncode: int, stdout: str) -> None:
-        self.returncode = returncode
-        self.stdout = stdout
-
-
-class InMemoryPip:
-    def pip(self, *args: Union[str, Path]) -> InMemoryPipResult:
-        orig_stdout = sys.stdout
-        stdout = io.StringIO()
-        sys.stdout = stdout
-        try:
-            returncode = pip_entry_point([os.fspath(a) for a in args])
-        except SystemExit as e:
-            returncode = e.code or 0
-        finally:
-            sys.stdout = orig_stdout
-        return InMemoryPipResult(returncode, stdout.getvalue())
-
-
 @pytest.fixture
 def in_memory_pip() -> InMemoryPip:
     return InMemoryPip()
@@ -662,9 +683,6 @@ def deprecated_python() -> bool:
     return sys.version_info[:2] in []
 
 
-CertFactory = Callable[[], str]
-
-
 @pytest.fixture(scope="session")
 def cert_factory(tmpdir_factory: pytest.TempPathFactory) -> CertFactory:
     # Delay the import requiring cryptography in order to make it possible
@@ -686,49 +704,6 @@ def cert_factory(tmpdir_factory: pytest.TempPathFactory) -> CertFactory:
     return factory
 
 
-class MockServer:
-    def __init__(self, server: _MockServer) -> None:
-        self._server = server
-        self._running = False
-        self.context = ExitStack()
-
-    @property
-    def port(self) -> int:
-        return self._server.port
-
-    @property
-    def host(self) -> str:
-        return self._server.host
-
-    def set_responses(self, responses: Iterable["WSGIApplication"]) -> None:
-        assert not self._running, "responses cannot be set on running server"
-        self._server.mock.side_effect = responses
-
-    def start(self) -> None:
-        assert not self._running, "running server cannot be started"
-        self.context.enter_context(server_running(self._server))
-        self.context.enter_context(self._set_running())
-
-    @contextmanager
-    def _set_running(self) -> Iterator[None]:
-        self._running = True
-        try:
-            yield
-        finally:
-            self._running = False
-
-    def stop(self) -> None:
-        assert self._running, "idle server cannot be stopped"
-        self.context.close()
-
-    def get_requests(self) -> List[Dict[str, str]]:
-        """Get environ for each received request."""
-        assert not self._running, "cannot get mock from running server"
-        # Legacy: replace call[0][0] with call.args[0]
-        # when pip drops support for python3.7
-        return [call[0][0] for call in self._server.mock.call_args_list]
-
-
 @pytest.fixture
 def mock_server() -> Iterator[MockServer]:
     server = make_mock_server()
@@ -745,3 +720,292 @@ def proxy(request: pytest.FixtureRequest) -> str:
 @pytest.fixture
 def enable_user_site(virtualenv: VirtualEnvironment) -> None:
     virtualenv.user_site_packages = True
+
+
+class MetadataKind(Enum):
+    """All the types of values we might be provided for the data-dist-info-metadata
+    attribute from PEP 658."""
+
+    # Valid: will read metadata from the dist instead.
+    No = "none"
+    # Valid: will read the .metadata file, but won't check its hash.
+    Unhashed = "unhashed"
+    # Valid: will read the .metadata file and check its hash matches.
+    Sha256 = "sha256"
+    # Invalid: will error out after checking the hash.
+    WrongHash = "wrong-hash"
+    # Invalid: will error out after failing to fetch the .metadata file.
+    NoFile = "no-file"
+
+
+@dataclass(frozen=True)
+class FakePackage:
+    """Mock package structure used to generate a PyPI repository.
+
+    FakePackage name and version should correspond to sdists (.tar.gz files) in our test
+    data."""
+
+    name: str
+    version: str
+    filename: str
+    metadata: MetadataKind
+    # This will override any dependencies specified in the actual dist's METADATA.
+    requires_dist: tuple[str, ...] = ()
+    # This will override the Name specified in the actual dist's METADATA.
+    metadata_name: str | None = None
+
+    def metadata_filename(self) -> str:
+        """This is specified by PEP 658."""
+        return f"{self.filename}.metadata"
+
+    def generate_additional_tag(self) -> str:
+        """This gets injected into the <a> tag in the generated PyPI index page for this
+        package."""
+        if self.metadata == MetadataKind.No:
+            return ""
+        if self.metadata in [MetadataKind.Unhashed, MetadataKind.NoFile]:
+            return 'data-dist-info-metadata="true"'
+        if self.metadata == MetadataKind.WrongHash:
+            return 'data-dist-info-metadata="sha256=WRONG-HASH"'
+        assert self.metadata == MetadataKind.Sha256
+        checksum = sha256(self.generate_metadata()).hexdigest()
+        return f'data-dist-info-metadata="sha256={checksum}"'
+
+    def requires_str(self) -> str:
+        if not self.requires_dist:
+            return ""
+        joined = " and ".join(self.requires_dist)
+        return f"Requires-Dist: {joined}"
+
+    def generate_metadata(self) -> bytes:
+        """This is written to `self.metadata_filename()` and will override the actual
+        dist's METADATA, unless `self.metadata == MetadataKind.NoFile`."""
+        return dedent(
+            f"""\
+        Metadata-Version: 2.1
+        Name: {self.metadata_name or self.name}
+        Version: {self.version}
+        {self.requires_str()}
+        """
+        ).encode("utf-8")
+
+
+@pytest.fixture(scope="session")
+def fake_packages() -> dict[str, list[FakePackage]]:
+    """The package database we generate for testing PEP 658 support."""
+    return {
+        "simple": [
+            FakePackage("simple", "1.0", "simple-1.0.tar.gz", MetadataKind.Sha256),
+            FakePackage("simple", "2.0", "simple-2.0.tar.gz", MetadataKind.No),
+            # This will raise a hashing error.
+            FakePackage("simple", "3.0", "simple-3.0.tar.gz", MetadataKind.WrongHash),
+        ],
+        "simple2": [
+            # Override the dependencies here in order to force pip to download
+            # simple-1.0.tar.gz as well.
+            FakePackage(
+                "simple2",
+                "1.0",
+                "simple2-1.0.tar.gz",
+                MetadataKind.Unhashed,
+                ("simple==1.0",),
+            ),
+            # This will raise an error when pip attempts to fetch the metadata file.
+            FakePackage("simple2", "2.0", "simple2-2.0.tar.gz", MetadataKind.NoFile),
+            # This has a METADATA file with a mismatched name.
+            FakePackage(
+                "simple2",
+                "3.0",
+                "simple2-3.0.tar.gz",
+                MetadataKind.Sha256,
+                metadata_name="not-simple2",
+            ),
+        ],
+        "colander": [
+            # Ensure we can read the dependencies from a metadata file within a wheel
+            # *without* PEP 658 metadata.
+            FakePackage(
+                "colander",
+                "0.9.9",
+                "colander-0.9.9-py2.py3-none-any.whl",
+                MetadataKind.No,
+            ),
+        ],
+        "compilewheel": [
+            # Ensure we can override the dependencies of a wheel file by injecting PEP
+            # 658 metadata.
+            FakePackage(
+                "compilewheel",
+                "1.0",
+                "compilewheel-1.0-py2.py3-none-any.whl",
+                MetadataKind.Unhashed,
+                ("simple==1.0",),
+            ),
+        ],
+        "has-script": [
+            # Ensure we check PEP 658 metadata hashing errors for wheel files.
+            FakePackage(
+                "has-script",
+                "1.0",
+                "has.script-1.0-py2.py3-none-any.whl",
+                MetadataKind.WrongHash,
+            ),
+        ],
+        "translationstring": [
+            FakePackage(
+                "translationstring",
+                "1.1",
+                "translationstring-1.1.tar.gz",
+                MetadataKind.No,
+            ),
+        ],
+        "priority": [
+            # Ensure we check for a missing metadata file for wheels.
+            FakePackage(
+                "priority",
+                "1.0",
+                "priority-1.0-py2.py3-none-any.whl",
+                MetadataKind.NoFile,
+            ),
+        ],
+        "requires-simple-extra": [
+            # Metadata name is not canonicalized.
+            FakePackage(
+                "requires-simple-extra",
+                "0.1",
+                "requires_simple_extra-0.1-py2.py3-none-any.whl",
+                MetadataKind.Sha256,
+                metadata_name="Requires_Simple.Extra",
+            ),
+        ],
+    }
+
+
+@pytest.fixture(scope="session")
+def html_index_for_packages(
+    shared_data: TestData,
+    fake_packages: dict[str, list[FakePackage]],
+    tmpdir_factory: pytest.TempPathFactory,
+) -> Path:
+    """Generate a PyPI HTML package index within a local directory pointing to
+    synthetic test data."""
+    html_dir = tmpdir_factory.mktemp("fake_index_html_content")
+
+    # (1) Generate the content for a PyPI index.html.
+    pkg_links = "\n".join(
+        f'    <a href="{pkg}/index.html">{pkg}</a>' for pkg in fake_packages.keys()
+    )
+    # Output won't be nicely indented because dedent() acts after f-string
+    # arg insertion.
+    index_html = dedent(
+        f"""\
+        <!DOCTYPE html>
+        <html>
+          <head>
+            <meta name="pypi:repository-version" content="1.0">
+            <title>Simple index</title>
+          </head>
+          <body>
+          {pkg_links}
+          </body>
+        </html>"""
+    )
+    # (2) Generate the index.html in a new subdirectory of the temp directory.
+    (html_dir / "index.html").write_text(index_html)
+
+    # (3) Generate subdirectories for individual packages, each with their own
+    # index.html.
+    for pkg, links in fake_packages.items():
+        pkg_subdir = html_dir / pkg
+        pkg_subdir.mkdir()
+
+        download_links: list[str] = []
+        for package_link in links:
+            # (3.1) Generate the <a> tag which pip can crawl pointing to this
+            # specific package version.
+            download_links.append(
+                f'    <a href="{package_link.filename}" {package_link.generate_additional_tag()}>{package_link.filename}</a><br/>'  # noqa: E501
+            )
+            # (3.2) Copy over the corresponding file in `shared_data.packages`.
+            shutil.copy(
+                shared_data.packages / package_link.filename,
+                pkg_subdir / package_link.filename,
+            )
+            # (3.3) Write a metadata file, if applicable.
+            if package_link.metadata != MetadataKind.NoFile:
+                with open(pkg_subdir / package_link.metadata_filename(), "wb") as f:
+                    f.write(package_link.generate_metadata())
+
+        # (3.4) After collating all the download links and copying over the files,
+        # write an index.html with the generated download links for each
+        # copied file for this specific package name.
+        download_links_str = "\n".join(download_links)
+        pkg_index_content = dedent(
+            f"""\
+            <!DOCTYPE html>
+            <html>
+              <head>
+                <meta name="pypi:repository-version" content="1.0">
+                <title>Links for {pkg}</title>
+              </head>
+              <body>
+                <h1>Links for {pkg}</h1>
+                {download_links_str}
+              </body>
+            </html>"""
+        )
+        with open(pkg_subdir / "index.html", "w") as f:
+            f.write(pkg_index_content)
+
+    return html_dir
+
+
+class OneTimeDownloadHandler(http.server.SimpleHTTPRequestHandler):
+    """Serve files from the current directory, but error if a file is downloaded more
+    than once."""
+
+    _seen_paths: ClassVar[set[str]] = set()
+
+    def do_GET(self) -> None:
+        if self.path in self._seen_paths:
+            self.send_error(
+                http.HTTPStatus.NOT_FOUND,
+                f"File {self.path} not available more than once!",
+            )
+            return
+        super().do_GET()
+        if not (self.path.endswith("/") or self.path.endswith(".metadata")):
+            self._seen_paths.add(self.path)
+
+
+@pytest.fixture
+def html_index_with_onetime_server(
+    html_index_for_packages: Path,
+) -> Iterator[http.server.ThreadingHTTPServer]:
+    """Serve files from a generated pypi index, erroring if a file is downloaded more
+    than once.
+
+    Provide `-i http://localhost:8000` to pip invocations to point them at this server.
+    """
+
+    class InDirectoryServer(http.server.ThreadingHTTPServer):
+        def finish_request(self: Self, request: Any, client_address: Any) -> None:
+            self.RequestHandlerClass(
+                request,
+                client_address,
+                self,
+                directory=str(html_index_for_packages),  # type: ignore[call-arg]
+            )
+
+    class Handler(OneTimeDownloadHandler):
+        _seen_paths: ClassVar[set[str]] = set()
+
+    with InDirectoryServer(("", 8000), Handler) as httpd:
+        server_thread = threading.Thread(target=httpd.serve_forever)
+        server_thread.start()
+
+        try:
+            yield httpd
+        finally:
+            httpd.shutdown()
+            server_thread.join()
