@@ -9,6 +9,7 @@ def test_find_links_relative_path(script: PipTestEnvironment, data: TestData) ->
     result = script.pip(
         "install",
         "parent==0.1",
+        "--no-build-isolation",
         "--no-index",
         "--find-links",
         "packages/",
@@ -27,6 +28,7 @@ def test_find_links_no_doctype(script: PipTestEnvironment, data: TestData) -> No
     result = script.pip(
         "install",
         "simple==1.0",
+        "--no-build-isolation",
         "--no-index",
         "--find-links",
         script.scratch_path,
@@ -50,6 +52,7 @@ def test_find_links_requirements_file_relative_path(
     )
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "-r",
         script.scratch_path / "test-req.txt",
         cwd=data.root,
@@ -67,7 +70,9 @@ def test_install_from_file_index_hash_link(
     Test that a pkg can be installed from a file:// index using a link with a
     hash
     """
-    result = script.pip("install", "-i", data.index_url(), "simple==1.0")
+    result = script.pip(
+        "install", "--no-build-isolation", "-i", data.index_url(), "simple==1.0"
+    )
     dist_info_folder = script.site_packages / "simple-1.0.dist-info"
     result.did_create(dist_info_folder)
 
@@ -77,6 +82,8 @@ def test_file_index_url_quoting(script: PipTestEnvironment, data: TestData) -> N
     Test url quoting of file index url with a space
     """
     index_url = data.index_url("in dex")
-    result = script.pip("install", "-vvv", "--index-url", index_url, "simple")
+    result = script.pip(
+        "install", "--no-build-isolation", "-vvv", "--index-url", index_url, "simple"
+    )
     result.did_create(script.site_packages / "simple")
     result.did_create(script.site_packages / "simple-1.0.dist-info")
