@@ -10,10 +10,10 @@ from tests.lib import (
     PipTestEnvironment,
     ResolverVariant,
     TestData,
+    _create_test_package,
     _create_test_package_with_subdirectory,
     create_basic_sdist_for_package,
     create_basic_wheel_for_package,
-    make_wheel,
     need_svn,
     requirements_file,
 )
@@ -188,8 +188,7 @@ def test_schema_check_in_requirements_file(script: PipTestEnvironment) -> None:
     """
     script.scratch_path.joinpath("file-egg-req.txt").write_text(
         "\n{}\n".format(
-            "git://github.com/alex/django-fixture-generator.git"
-            "#egg=fixture_generator"
+            "git://github.com/alex/django-fixture-generator.git#egg=fixture_generator"
         )
     )
 
@@ -217,7 +216,6 @@ def test_relative_requirements_file(
 
     """
     dist_info_folder = script.site_packages / "fspkg-0.1.dev0.dist-info"
-    egg_link_file = script.site_packages / "FSPkg.egg-link"
     package_folder = script.site_packages / "fspkg"
 
     # Compute relative install path to FSPkg from scratch path.
@@ -238,7 +236,12 @@ def test_relative_requirements_file(
     if not editable:
         with requirements_file(req_path + "\n", script.scratch_path) as reqs_file:
             result = script.pip(
-                "install", "-vvv", "-r", reqs_file.name, cwd=script.scratch_path
+                "install",
+                "--no-build-isolation",
+                "-vvv",
+                "-r",
+                reqs_file.name,
+                cwd=script.scratch_path,
             )
             result.did_create(dist_info_folder)
             result.did_create(package_folder)
@@ -247,9 +250,16 @@ def test_relative_requirements_file(
             "-e " + req_path + "\n", script.scratch_path
         ) as reqs_file:
             result = script.pip(
-                "install", "-vvv", "-r", reqs_file.name, cwd=script.scratch_path
+                "install",
+                "--no-build-isolation",
+                "-vvv",
+                "-r",
+                reqs_file.name,
+                cwd=script.scratch_path,
             )
-            result.did_create(egg_link_file)
+            direct_url = result.get_created_direct_url("fspkg")
+            assert direct_url
+            assert direct_url.is_local_editable()
 
 
 @pytest.mark.xfail
@@ -290,6 +300,7 @@ def test_package_in_constraints_and_dependencies(
     )
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -315,6 +326,7 @@ def test_constraints_apply_to_dependency_groups(
     )
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -331,6 +343,7 @@ def test_multiple_constraints_files(script: PipTestEnvironment, data: TestData)
     script.scratch_path.joinpath("inner.txt").write_text("Upper==1.0")
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -357,6 +370,7 @@ def test_respect_order_in_requirements_file(
 
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -384,9 +398,8 @@ def test_install_local_editable_with_extras(
     res = script.pip_install_local(
         "-e", f"{to_install}[bar]", allow_stderr_warning=True
     )
-    res.did_update(script.site_packages / "easy-install.pth")
-    res.did_create(script.site_packages / "LocalExtras.egg-link")
-    res.did_create(script.site_packages / "simple")
+    res.assert_installed("LocalExtras", editable=True, editable_vcs=False)
+    res.assert_installed("simple", editable=False)
 
 
 def test_install_collected_dependencies_first(script: PipTestEnvironment) -> None:
@@ -444,7 +457,13 @@ def test_wheel_user_with_prefix_in_pydistutils_cfg(
         )
 
     result = script.pip(
-        "install", "--user", "--no-index", "-f", data.find_links, "requiresupper"
+        "install",
+        "--no-build-isolation",
+        "--user",
+        "--no-index",
+        "-f",
+        data.find_links,
+        "requiresupper",
     )
     # Check that we are really installing a wheel
     assert "installed requiresupper" in result.stdout
@@ -456,6 +475,7 @@ def test_constraints_not_installed_by_default(
     script.scratch_path.joinpath("c.txt").write_text("requiresupper")
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -491,6 +511,7 @@ def test_constraints_local_editable_install_causes_error(
     to_install = data.src.joinpath("singlemodule")
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -523,6 +544,7 @@ def test_constraints_local_install_causes_error(
     to_install = data.src.joinpath("singlemodule")
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -570,6 +592,7 @@ def test_constraints_constrain_to_local(
     )
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -589,6 +612,7 @@ def test_constrained_to_url_install_same_url(
     script.scratch_path.joinpath("constraints.txt").write_text(constraints)
     result = script.pip(
         "install",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.find_links,
@@ -817,8 +841,7 @@ def test_install_unsupported_wheel_link_with_marker(script: PipTestEnvironment)
     result = script.pip("install", "-r", script.scratch_path / "with-marker.txt")
 
     assert (
-        "Ignoring asdf: markers 'sys_platform == \"xyz\"' don't match "
-        "your environment"
+        "Ignoring asdf: markers 'sys_platform == \"xyz\"' don't match your environment"
     ) in result.stdout
     assert len(result.files_created) == 0
 
@@ -920,24 +943,50 @@ def test_config_settings_local_to_package(
     assert "--verbose" not in simple2_args
 
 
-def test_nonpep517_setuptools_import_failure(script: PipTestEnvironment) -> None:
-    """Any import failures of `setuptools` should inform the user both that it's
-    not pip's fault, but also exactly what went wrong in the import."""
-    # Install a poisoned version of 'setuptools' that fails to import.
-    name = "setuptools_poisoned"
-    module = """\
-raise ImportError("this 'setuptools' was intentionally poisoned")
-"""
-    path = make_wheel(name, "0.1.0", extra_files={"setuptools.py": module}).save_to_dir(
-        script.scratch_path
-    )
-    script.pip("install", "--no-index", path)
+class TestEditableDirectURL:
+    def test_install_local_project(
+        self, script: PipTestEnvironment, data: TestData, common_wheels: Path
+    ) -> None:
+        uri = (data.src / "simplewheel-2.0").as_uri()
+        script.pip(
+            "install", "--no-index", "-e", f"simplewheel @ {uri}", "-f", common_wheels
+        )
+        script.assert_installed(simplewheel="2.0")
 
-    result = script.pip_install_local("--no-use-pep517", "simple", expect_error=True)
-    nice_message = (
-        "ERROR: Can not execute `setup.py`"
-        " since setuptools failed to import in the build environment"
-    )
-    exc_message = "ImportError: this 'setuptools' was intentionally poisoned"
-    assert nice_message in result.stderr
-    assert exc_message in result.stderr
+    def test_install_local_project_with_extra(
+        self, script: PipTestEnvironment, data: TestData, common_wheels: Path
+    ) -> None:
+        uri = (data.src / "requires_simple_extra").as_uri()
+        script.pip(
+            "install",
+            "--no-index",
+            "-e",
+            f"requires-simple-extra[extra] @ {uri}",
+            "-f",
+            common_wheels,
+            "-f",
+            data.packages,
+        )
+        script.assert_installed(requires_simple_extra="0.1")
+        script.assert_installed(simple="1.0")
+
+    def test_install_local_git_repo(
+        self, script: PipTestEnvironment, common_wheels: Path
+    ) -> None:
+        repo_path = _create_test_package(script.scratch_path, "simple")
+        url = "git+" + repo_path.as_uri()
+        script.pip(
+            "install", "--no-index", "-e", f"simple @ {url}", "-f", common_wheels
+        )
+        script.assert_installed(simple="0.1")
+
+    @pytest.mark.network
+    def test_install_remote_git_repo_with_extra(
+        self, script: PipTestEnvironment, data: TestData, common_wheels: Path
+    ) -> None:
+        req = "pip-test-package[extra] @ git+https://github.com/pypa/pip-test-package"
+        script.pip(
+            "install", "--no-index", "-e", req, "-f", common_wheels, "-f", data.packages
+        )
+        script.assert_installed(pip_test_package="0.1.1")
+        script.assert_installed(simple="3.0")
