@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 from typing import Any
 
+import pytest
 import tomli_w
 
 from tests.lib import PipTestEnvironment
@@ -164,53 +165,31 @@ def test_install_pep660_from_reqs_file(
     ), "a .egg-link file should not have been created"
 
 
-def test_install_no_pep660_setup_py_fallback(
-    tmpdir: Path, script: PipTestEnvironment
+@pytest.mark.parametrize("isolation_arg", [[], ["--no-build-isolation"]])
+def test_install_no_pep660(
+    isolation_arg: list[str],
+    tmpdir: Path,
+    script: PipTestEnvironment,
+    common_wheels: Path,
 ) -> None:
     """
-    Test that we fall back to setuptools develop when using a backend that
-    does not support build_editable. Since there is a pyproject.toml,
-    the prepare_metadata_for_build_wheel hook is called.
+    Test the error message when the build backend does not support PEP 660.
+
+    The error is the same with and without build isolation.
     """
     project_dir = _make_project(tmpdir, BACKEND_WITHOUT_PEP660, with_setup_py=True)
     result = script.pip(
         "install",
         "--no-index",
-        "--no-build-isolation",
+        "-f",
+        common_wheels,
+        *isolation_arg,
         "--editable",
         project_dir,
-        allow_stderr_warning=False,
+        allow_error=True,
     )
-    _assert_hook_called(project_dir, "prepare_metadata_for_build_wheel")
-    assert (
-        result.test_env.site_packages.joinpath("project.egg-link")
-        in result.files_created
-    ), "a .egg-link file should have been created"
-
-
-def test_install_no_pep660_setup_cfg_fallback(
-    tmpdir: Path, script: PipTestEnvironment
-) -> None:
-    """
-    Test that we fall back to setuptools develop when using a backend that
-    does not support build_editable. Since there is a pyproject.toml,
-    the prepare_metadata_for_build_wheel hook is called.
-    """
-    project_dir = _make_project(tmpdir, BACKEND_WITHOUT_PEP660, with_setup_py=False)
-    result = script.pip(
-        "install",
-        "--no-index",
-        "--no-build-isolation",
-        "--editable",
-        project_dir,
-        allow_stderr_warning=False,
-    )
-    print(result.stdout, result.stderr)
-    _assert_hook_called(project_dir, "prepare_metadata_for_build_wheel")
-    assert (
-        result.test_env.site_packages.joinpath("project.egg-link")
-        in result.files_created
-    ), ".egg-link file should have been created"
+    assert result.returncode != 0
+    assert "missing the 'build_editable' hook" in result.stderr
 
 
 def test_wheel_editable_pep660_basic(tmpdir: Path, script: PipTestEnvironment) -> None:
