@@ -1,7 +1,10 @@
 """Helper classes as mocks for requests objects."""
 
+from __future__ import annotations
+
+from collections.abc import Iterator
 from io import BytesIO
-from typing import Any, Callable, Dict, Iterator, List, Optional
+from typing import Any, Callable
 
 _Hook = Callable[["MockResponse"], None]
 
@@ -10,12 +13,10 @@ class FakeStream:
     def __init__(self, contents: bytes) -> None:
         self._io = BytesIO(contents)
 
-    def read(self, size: int, decode_content: Optional[bool] = None) -> bytes:
+    def read(self, size: int, decode_content: bool | None = None) -> bytes:
         return self._io.read(size)
 
-    def stream(
-        self, size: int, decode_content: Optional[bool] = None
-    ) -> Iterator[bytes]:
+    def stream(self, size: int, decode_content: bool | None = None) -> Iterator[bytes]:
         yield self._io.read(size)
 
     def release_conn(self) -> None:
@@ -23,8 +24,8 @@ class FakeStream:
 
 
 class MockResponse:
-    request: "MockRequest"
-    connection: "MockConnection"
+    request: MockRequest
+    connection: MockConnection
     url: str
 
     def __init__(self, contents: bytes) -> None:
@@ -33,15 +34,15 @@ class MockResponse:
         self.reason = "OK"
         self.status_code = 200
         self.headers = {"Content-Length": str(len(contents))}
-        self.history: List[MockResponse] = []
+        self.history: list[MockResponse] = []
         self.from_cache = False
 
 
 class MockConnection:
-    def _send(self, req: "MockRequest", **kwargs: Any) -> MockResponse:
+    def _send(self, req: MockRequest, **kwargs: Any) -> MockResponse:
         raise NotImplementedError("_send must be overridden for tests")
 
-    def send(self, req: "MockRequest", **kwargs: Any) -> MockResponse:
+    def send(self, req: MockRequest, **kwargs: Any) -> MockResponse:
         resp = self._send(req, **kwargs)
         for cb in req.hooks.get("response", []):
             cb(resp)
@@ -51,8 +52,8 @@ class MockConnection:
 class MockRequest:
     def __init__(self, url: str) -> None:
         self.url = url
-        self.headers: Dict[str, str] = {}
-        self.hooks: Dict[str, List[_Hook]] = {}
+        self.headers: dict[str, str] = {}
+        self.hooks: dict[str, list[_Hook]] = {}
 
     def register_hook(self, event_name: str, callback: _Hook) -> None:
         self.hooks.setdefault(event_name, []).append(callback)
