@@ -1,13 +1,14 @@
 import os
 from pathlib import Path
-from typing import Iterator, List, Tuple
 
 import pytest
+
 from pip._vendor.resolvelib import BaseReporter, Resolver
 
 from pip._internal.resolution.resolvelib.base import Candidate, Constraint, Requirement
 from pip._internal.resolution.resolvelib.factory import Factory
 from pip._internal.resolution.resolvelib.provider import PipProvider
+
 from tests.lib import TestData
 
 # NOTE: All tests are prefixed `test_rlr` (for "test resolvelib resolver").
@@ -32,7 +33,7 @@ def _is_satisfied_by(requirement: Requirement, candidate: Candidate) -> bool:
 
 
 @pytest.fixture
-def test_cases(data: TestData) -> Iterator[List[Tuple[str, str, int]]]:
+def test_cases(data: TestData) -> list[tuple[str, str, int]]:
     def _data_file(name: str) -> Path:
         return data.packages.joinpath(name)
 
@@ -61,11 +62,11 @@ def test_cases(data: TestData) -> Iterator[List[Tuple[str, str, int]]]:
         # TODO: directory, editables
     ]
 
-    yield test_cases
+    return test_cases
 
 
 def test_new_resolver_requirement_has_name(
-    test_cases: List[Tuple[str, str, int]], factory: Factory
+    test_cases: list[tuple[str, str, int]], factory: Factory
 ) -> None:
     """All requirements should have a name"""
     for spec, name, _ in test_cases:
@@ -75,7 +76,7 @@ def test_new_resolver_requirement_has_name(
 
 
 def test_new_resolver_correct_number_of_matches(
-    test_cases: List[Tuple[str, str, int]], factory: Factory
+    test_cases: list[tuple[str, str, int]], factory: Factory
 ) -> None:
     """Requirements should return the correct number of candidates"""
     for spec, _, match_count in test_cases:
@@ -94,7 +95,7 @@ def test_new_resolver_correct_number_of_matches(
 
 
 def test_new_resolver_candidates_match_requirement(
-    test_cases: List[Tuple[str, str, int]], factory: Factory
+    test_cases: list[tuple[str, str, int]], factory: Factory
 ) -> None:
     """Candidates returned from find_candidates should satisfy the requirement"""
     for spec, _, _ in test_cases:
