@@ -1,63 +1,58 @@
 import os
 import sys
-import urllib.request
+import urllib.parse
 
 import pytest
 
 from pip._internal.utils.urls import path_to_url, url_to_path
-from tests.lib import (
-    skip_needs_new_urlun_behavior_win,
-    skip_needs_old_urlun_behavior_win,
-)
 
 
 @pytest.mark.skipif("sys.platform == 'win32'")
 def test_path_to_url_unix() -> None:
     assert path_to_url("/tmp/file") == "file:///tmp/file"
     path = os.path.join(os.getcwd(), "file")
-    assert path_to_url("file") == "file://" + urllib.request.pathname2url(path)
+    assert path_to_url("file") == "file://" + urllib.parse.quote(path)
 
 
 @pytest.mark.skipif("sys.platform != 'win32'")
 @pytest.mark.parametrize(
     "path, url",
     [
-        pytest.param("c:/tmp/file", "file:///C:/tmp/file", id="posix-path"),
-        pytest.param("c:\\tmp\\file", "file:///C:/tmp/file", id="nt-path"),
-        pytest.param(
-            r"\\unc\as\path",
-            "file://unc/as/path",
-            marks=skip_needs_old_urlun_behavior_win,
-            id="unc-path",
-        ),
-        pytest.param(
-            r"\\unc\as\path",
-            "file:////unc/as/path",
-            marks=skip_needs_new_urlun_behavior_win,
-        ),
+        pytest.param("C:/tmp/file", "file:///C:/tmp/file", id="posix-path"),
+        pytest.param("C:\\tmp\\file", "file:///C:/tmp/file", id="nt-path"),
     ],
 )
 def test_path_to_url_win(path: str, url: str) -> None:
     assert path_to_url(path) == url
 
 
+@pytest.mark.skipif("sys.platform != 'win32'")
+def test_unc_path_to_url_win() -> None:
+    # The two and four slash forms are both acceptable for our purposes. CPython's
+    # behaviour has changed several times here, so blindly accept either.
+    # - https://github.com/python/cpython/issues/78457
+    # - https://github.com/python/cpython/issues/126205
+    url = path_to_url(r"\\unc\as\path")
+    assert url in ["file://unc/as/path", "file:////unc/as/path"]
+
+
 @pytest.mark.skipif("sys.platform != 'win32'")
 def test_relative_path_to_url_win() -> None:
-    resolved_path = os.path.join(os.getcwd(), "file")
-    assert path_to_url("file") == "file:" + urllib.request.pathname2url(resolved_path)
+    path = os.path.join(os.getcwd(), "file").replace("\\", "/")
+    assert path_to_url("file") == "file:///" + urllib.parse.quote(path, safe="/:")
 
 
 @pytest.mark.parametrize(
     "url,win_expected,non_win_expected",
     [
         ("file:tmp", "tmp", "tmp"),
-        ("file:c:/path/to/file", r"C:\path\to\file", "c:/path/to/file"),
+        ("file:C:/path/to/file", r"C:\path\to\file", "C:/path/to/file"),
         ("file:/path/to/file", r"\path\to\file", "/path/to/file"),
         ("file://localhost/tmp/file", r"\tmp\file", "/tmp/file"),
-        ("file://localhost/c:/tmp/file", r"C:\tmp\file", "/c:/tmp/file"),
+        ("file://localhost/C:/tmp/file", r"C:\tmp\file", "/C:/tmp/file"),
         ("file://somehost/tmp/file", r"\\somehost\tmp\file", None),
         ("file:///tmp/file", r"\tmp\file", "/tmp/file"),
-        ("file:///c:/tmp/file", r"C:\tmp\file", "/c:/tmp/file"),
+        ("file:///C:/tmp/file", r"C:\tmp\file", "/C:/tmp/file"),
     ],
 )
 def test_url_to_path(url: str, win_expected: str, non_win_expected: str) -> None:
